@@ -4,8 +4,8 @@ import sys
 import click
 import shutil
 
-from Maverick.Builder import Builder
-from Maverick.Config import g_conf
+from .Maverick.Builder import Builder
+from .Maverick.Config import g_conf
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 work_path = os.path.abspath('.')
